import { LoaderFunctionArgs } from "@remix-run/node"; // Import LoaderFunctionArgs
import { useLoaderData } from "@remix-run/react";
import { Card, Layout, Page, Text, Button, Box } from "@shopify/polaris";
import { authenticate } from "app/shopify.server";

export const loader = async ({ request }: LoaderFunctionArgs) => {
    const { admin } = await authenticate.admin(request);
    const response = await admin.graphql(`
        #graphql
        query fetchShop {
            shop {
                id
                name
            }
        }`);
    const shopData = (await response.json()).data;
    console.log(shopData);

    // Use a Response object directly instead of the deprecated `json` function
    return new Response(JSON.stringify({ shop: shopData.shop }), {
        headers: { "Content-Type": "application/json" },
    });
};

export default function Products() {
    const { shop } = useLoaderData<typeof loader>();

    return (
        <Page>
            <ui-title-bar title="Products">
                <button
                    variant="primary"
                    onClick={() => {
                        shopify.modal.show("products-modal");
                    }}
                >
                    Create New
                </button>
            </ui-title-bar>
            <ui-modal id="products-modal">
                <ui-title-bar title="New Product">
                    <button variant="primary">OK</button>
                </ui-title-bar>
                <Box padding="500">
                    This is a new products that This is a new products that This is a new products that.
                </Box>
            </ui-modal>

            <Layout>
                <Layout.Section>
                    <Card>
                        <Text as="span" variant="bodyLg">
                            {shop.name}
                        </Text>
                        <Text as="h5" variant="bodyMd">
                            Products Page
                        </Text>
                        <Button onClick={() => shopify.toast.show("Hello world!")}>
                            Button
                        </Button>
                    </Card>
                </Layout.Section>
            </Layout>
        </Page>
    );
}